﻿/// Copyright (c) 2021 Iiro Iivanainen, Harri Linna, Jere Pakkanen, Riikka Vilavaara
/// 
/// Permission is hereby granted, free of charge, to any person obtaining
/// a copy of this software and associated documentation files (the
/// "Software"), to deal in the Software without restriction, including
/// without limitation the rights to use, copy, modify, merge, publish,
/// distribute, sublicense, and/or sell copies of the Software, and to
/// permit persons to whom the Software is furnished to do so, subject to
/// the following conditions:
/// 
/// The above copyright notice and this permission notice shall be included
/// in all copies or substantial portions of the Software.
/// 
/// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
/// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
/// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
/// IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
/// CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
/// TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
/// SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
/// 

using System.Text.Json.Serialization;

namespace CoreLibrary
{
    /// <summary>
    /// Meta class contains name and value of a single meta data. Could be replaced with a directory 
    /// data structure.
    /// </summary>
    public class Meta
    {
        public string Name { get; set; }
        public string Info { get; set; }

        /// <summary>
        /// Constructor for JSON serialization and deserialization. Note that the 
        /// parameter names must match the attribute names (non case sensitive)
        /// </summary>
        /// <param name="name"></param>
        /// <param name="info"></param>
        [JsonConstructor]
        public Meta(string name, string info)
        {
            Name = name;
            Info = info;
        }


        /// <summary>
        /// Default constructor of Meta.
        /// </summary>
        public Meta ()
        {

        }
    }
}
