﻿/// Copyright (c) 2021 Iiro Iivanainen, Harri Linna, Jere Pakkanen, Riikka Vilavaara
/// 
/// Permission is hereby granted, free of charge, to any person obtaining
/// a copy of this software and associated documentation files (the
/// "Software"), to deal in the Software without restriction, including
/// without limitation the rights to use, copy, modify, merge, publish,
/// distribute, sublicense, and/or sell copies of the Software, and to
/// permit persons to whom the Software is furnished to do so, subject to
/// the following conditions:
/// 
/// The above copyright notice and this permission notice shall be included
/// in all copies or substantial portions of the Software.
/// 
/// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
/// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
/// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
/// IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
/// CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
/// TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
/// SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
/// 

using System.Windows;
using System.Windows.Media;


namespace GroundhogApp.Dialogs
{
    /// <summary>
    /// Interaction logic for ConfigurationDialog.xaml
    /// </summary>
    public partial class ConfigurationDialog : Window
    {

        public string UserName { get; set; }
        public Color ZColor { get; set; }
        public Color XColor { get; set; }
        public Color YColor { get; set; }
        public Color DataOnMapColor { get; set; }
        public Color DataHighlightColor { get; set; }

        public ConfigurationDialog()
        {
            InitializeComponent();
            ResetUserName();
            ResetAxisColor();
        }

        public ConfigurationDialog(string userName, Color ZColor, Color XColor, Color YColor, Color DataOnMap, Color DataHighlight)
        {
            InitializeComponent();

            UserNameTextBox.Text = userName;
            
            ZColorPicker.SelectedColor = ZColor;
            XColorPicker.SelectedColor = XColor;
            YColorPicker.SelectedColor = YColor;

            DataOnMapColorPicker.SelectedColor = DataOnMap;
            DataHighlightColorPicker.SelectedColor = DataHighlight;
        }


        /// <summary>
        /// Click hander for resetting the username.
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void ResetUserName_Click(object sender, RoutedEventArgs e)
        {
            ResetUserName();
        }

        /// <summary>
        /// Resets username to default.
        /// </summary>
        private void ResetUserName()
        {
            UserNameTextBox.Text = Utilities.GetEnvironmentUser();
        }


        /// <summary>
        /// Click handler for resetting axis colors.
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void ResetAxisColor_Click(object sender, RoutedEventArgs e)
        {
            ResetAxisColor();
        }

        /// <summary>
        /// Reset axis colors to default values.
        /// </summary>
        private void ResetAxisColor()
        {
            ZColorPicker.SelectedColor = Colors.Green;
            XColorPicker.SelectedColor = Colors.Red;
            YColorPicker.SelectedColor = Colors.Blue;
        }


        /// <summary>
        /// Close the dialog.
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void CancelButton_Click(object sender, RoutedEventArgs e)
        {
            DialogResult = false;
        }


        /// <summary>
        /// Close the dialog and set the return values.
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void SaveButton_Click(object sender, RoutedEventArgs e)
        {
            UserName = UserNameTextBox.Text;
            ZColor = (Color)ZColorPicker.SelectedColor;
            XColor = (Color)XColorPicker.SelectedColor;
            YColor = (Color)YColorPicker.SelectedColor;

            DataOnMapColor = (Color)DataOnMapColorPicker.SelectedColor;
            DataHighlightColor = (Color)DataHighlightColorPicker.SelectedColor;

            DialogResult = true;
        }


        /// <summary>
        /// Click handler for resetting data colors..
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void ResetDataColor_Click(object sender, RoutedEventArgs e)
        {
            ResetDataColor();
        }


        /// <summary>
        /// Resets data colors displayed on the map to default values.
        /// </summary>
        private void ResetDataColor()
        {
            DataOnMapColorPicker.SelectedColor = Colors.Red;
            DataHighlightColorPicker.SelectedColor = Colors.Orange;
        }
    }
}
