/// Copyright (c) 2021 Iiro Iivanainen, Harri Linna, Jere Pakkanen, Riikka Vilavaara
/// 
/// Permission is hereby granted, free of charge, to any person obtaining
/// a copy of this software and associated documentation files (the
/// "Software"), to deal in the Software without restriction, including
/// without limitation the rights to use, copy, modify, merge, publish,
/// distribute, sublicense, and/or sell copies of the Software, and to
/// permit persons to whom the Software is furnished to do so, subject to
/// the following conditions:
/// 
/// The above copyright notice and this permission notice shall be included
/// in all copies or substantial portions of the Software.
/// 
/// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
/// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
/// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
/// IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
/// CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
/// TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
/// SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

using System;
using System.Numerics;

namespace WPFOpenGL
{
    public static class MathHelper
    {
        public static Vector3 RotateX(Vector3 direction, float radians)
        {
            return new Vector3(
                direction.X,
                direction.Y * MathF.Cos(radians) -
                direction.Z * MathF.Sin(radians),
                direction.Y * MathF.Sin(radians) +
                direction.Z * MathF.Cos(radians));
        }

        public static Vector3 RotateY(Vector3 direction, float radians)
        {
            return new Vector3(
                direction.X * MathF.Cos(radians) +
                direction.Z * MathF.Sin(radians),
                direction.Y,
                -direction.X * MathF.Sin(radians) +
                direction.Z * MathF.Cos(radians));
        }

        public static Vector3 RotateZ(Vector3 direction, float radians)
        {
            return new Vector3(
                direction.X * MathF.Cos(radians) -
                direction.Y * MathF.Sin(radians),
                direction.X * MathF.Sin(radians) +
                direction.Y * MathF.Cos(radians),
                direction.Z
            );
        }

        public static float DegreesToRadians(float degrees)
        {
            return degrees * (MathF.PI / 180f);
        }

        public static float RadiansToDegrees(float radians)
        {
            return radians * (180f / MathF.PI);
        }
    }
}
